/* sidebar.c generated by valac 0.18.0.79-04df6, the Vala compiler
 * generated from sidebar.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <clutter/clutter.h>
#include <gtk/gtk.h>
#include <clutter-gtk/clutter-gtk.h>
#include <gio/gio.h>
#include <float.h>
#include <math.h>
#include <cairo.h>
#include <libcommon.h>
#include <gdk-pixbuf/gdk-pixbuf.h>


#define BOXES_TYPE_SIDEBAR_PAGE (boxes_sidebar_page_get_type ())

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UI, BoxesUIClass))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_IS_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UI))
#define BOXES_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UI, BoxesUIClass))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIClass BoxesUIClass;
typedef struct _BoxesUIPrivate BoxesUIPrivate;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;
typedef struct _BoxesSidebarPrivate BoxesSidebarPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_CLUTTER_WIDGET (boxes_clutter_widget_get_type ())
#define BOXES_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidget))
#define BOXES_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))
#define BOXES_IS_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_IS_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_CLUTTER_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))

typedef struct _BoxesClutterWidget BoxesClutterWidget;
typedef struct _BoxesClutterWidgetClass BoxesClutterWidgetClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_REVEALER (boxes_revealer_get_type ())
#define BOXES_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REVEALER, BoxesRevealer))
#define BOXES_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REVEALER, BoxesRevealerClass))
#define BOXES_IS_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REVEALER))
#define BOXES_IS_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REVEALER))
#define BOXES_REVEALER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REVEALER, BoxesRevealerClass))

typedef struct _BoxesRevealer BoxesRevealer;
typedef struct _BoxesRevealerClass BoxesRevealerClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;
#define _cairo_pattern_destroy0(var) ((var == NULL) ? NULL : (var = (cairo_pattern_destroy (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

typedef enum  {
	BOXES_SIDEBAR_PAGE_COLLECTION,
	BOXES_SIDEBAR_PAGE_WIZARD,
	BOXES_SIDEBAR_PAGE_PROPERTIES
} BoxesSidebarPage;

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_SETTINGS,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUI {
	GObject parent_instance;
	BoxesUIPrivate * priv;
	BoxesUIState previous_ui_state;
};

struct _BoxesUIClass {
	GObjectClass parent_class;
	void (*ui_state_changed) (BoxesUI* self);
	ClutterActor* (*get_actor) (BoxesUI* self);
};

struct _BoxesSidebar {
	BoxesUI parent_instance;
	BoxesSidebarPrivate * priv;
	GtkNotebook* notebook;
};

struct _BoxesSidebarClass {
	BoxesUIClass parent_class;
};

struct _BoxesSidebarPrivate {
	guint width;
	ClutterActor* bin_actor;
	GtkClutterActor* gtk_actor;
};

struct _BoxesApp {
	BoxesUI parent_instance;
	BoxesAppPrivate * priv;
	GtkApplicationWindow* window;
	GtkNotebook* notebook;
	BoxesClutterWidget* embed;
	ClutterStage* stage;
	ClutterBinLayout* stage_bin;
	ClutterActor* overlay_bin_actor;
	ClutterBinLayout* overlay_bin;
	BoxesCollectionItem* current_item;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesRevealer* sidebar_revealer;
	BoxesRevealer* searchbar_revealer;
	BoxesSidebar* sidebar;
	BoxesSelectionbar* selectionbar;
	guint duration;
	GSettings* settings;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
	BoxesCollectionView* view;
};

struct _BoxesAppClass {
	BoxesUIClass parent_class;
};


static gpointer boxes_sidebar_parent_class = NULL;
extern BoxesApp* boxes_app_app;

GType boxes_sidebar_page_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
#define BOXES_SIDEBAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_SIDEBAR, BoxesSidebarPrivate))
enum  {
	BOXES_SIDEBAR_DUMMY_PROPERTY,
	BOXES_SIDEBAR_ACTOR
};
#define BOXES_SIDEBAR_shadow_width 7
BoxesSidebar* boxes_sidebar_new (void);
BoxesSidebar* boxes_sidebar_construct (GType object_type);
BoxesUI* boxes_ui_construct (GType object_type);
static void boxes_sidebar_setup_sidebar (BoxesSidebar* self);
static void boxes_sidebar_real_ui_state_changed (BoxesUI* base);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_clutter_widget_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_revealer_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
void boxes_revealer_reveal (BoxesRevealer* self);
void boxes_revealer_unreveal (BoxesRevealer* self);
static gboolean __lambda42_ (BoxesSidebar* self, cairo_t* cr, gint w, gint h);
static gboolean ___lambda42__clutter_canvas_draw (ClutterCanvas* _sender, cairo_t* cr, gint width, gint height, gpointer self);
static void boxes_sidebar_finalize (GObject* obj);
ClutterActor* boxes_ui_get_actor (BoxesUI* self);
static void _vala_boxes_sidebar_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);


GType boxes_sidebar_page_get_type (void) {
	static volatile gsize boxes_sidebar_page_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_sidebar_page_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_SIDEBAR_PAGE_COLLECTION, "BOXES_SIDEBAR_PAGE_COLLECTION", "collection"}, {BOXES_SIDEBAR_PAGE_WIZARD, "BOXES_SIDEBAR_PAGE_WIZARD", "wizard"}, {BOXES_SIDEBAR_PAGE_PROPERTIES, "BOXES_SIDEBAR_PAGE_PROPERTIES", "properties"}, {0, NULL, NULL}};
		GType boxes_sidebar_page_type_id;
		boxes_sidebar_page_type_id = g_enum_register_static ("BoxesSidebarPage", values);
		g_once_init_leave (&boxes_sidebar_page_type_id__volatile, boxes_sidebar_page_type_id);
	}
	return boxes_sidebar_page_type_id__volatile;
}


BoxesSidebar* boxes_sidebar_construct (GType object_type) {
	BoxesSidebar * self = NULL;
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	self = (BoxesSidebar*) boxes_ui_construct (object_type);
#line 22 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	self->priv->width = (guint) 200;
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	boxes_sidebar_setup_sidebar (self);
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	return self;
#line 344 "sidebar.c"
}


BoxesSidebar* boxes_sidebar_new (void) {
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	return boxes_sidebar_construct (BOXES_TYPE_SIDEBAR);
#line 351 "sidebar.c"
}


static void boxes_sidebar_real_ui_state_changed (BoxesUI* base) {
	BoxesSidebar * self;
	BoxesUIState _tmp0_;
	BoxesUIState _tmp1_;
#line 27 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	self = (BoxesSidebar*) base;
#line 28 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp0_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 28 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp1_ = _tmp0_;
#line 28 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	switch (_tmp1_) {
#line 28 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
		case BOXES_UI_STATE_WIZARD:
#line 28 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
		case BOXES_UI_STATE_PROPERTIES:
#line 371 "sidebar.c"
		{
			BoxesApp* _tmp2_;
			BoxesRevealer* _tmp3_;
			BoxesSidebarPage _tmp4_ = 0;
			BoxesUIState _tmp5_;
			BoxesUIState _tmp6_;
			GtkNotebook* _tmp7_;
			BoxesSidebarPage _tmp8_;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
			_tmp2_ = boxes_app_app;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
			_tmp3_ = _tmp2_->sidebar_revealer;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
			boxes_revealer_reveal (_tmp3_);
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
			_tmp5_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
			_tmp6_ = _tmp5_;
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
			if (_tmp6_ == BOXES_UI_STATE_WIZARD) {
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
				_tmp4_ = BOXES_SIDEBAR_PAGE_WIZARD;
#line 394 "sidebar.c"
			} else {
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
				_tmp4_ = BOXES_SIDEBAR_PAGE_PROPERTIES;
#line 398 "sidebar.c"
			}
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
			_tmp7_ = self->notebook;
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
			_tmp8_ = _tmp4_;
#line 32 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
			g_object_set (_tmp7_, "page", (gint) _tmp8_, NULL);
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
			break;
#line 408 "sidebar.c"
		}
		default:
		{
			BoxesApp* _tmp9_;
			BoxesRevealer* _tmp10_;
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
			_tmp9_ = boxes_app_app;
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
			_tmp10_ = _tmp9_->sidebar_revealer;
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
			boxes_revealer_unreveal (_tmp10_);
#line 37 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
			break;
#line 422 "sidebar.c"
		}
	}
}


static gboolean __lambda42_ (BoxesSidebar* self, cairo_t* cr, gint w, gint h) {
	gboolean result = FALSE;
	gint _tmp0_;
	cairo_pattern_t* _tmp1_;
	cairo_pattern_t* p;
	cairo_t* _tmp2_;
	cairo_t* _tmp3_;
	cairo_t* _tmp4_;
	gint _tmp5_;
	gint _tmp6_;
	cairo_t* _tmp7_;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_return_val_if_fail (cr != NULL, FALSE);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp0_ = w;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp1_ = cairo_pattern_create_linear ((gdouble) 0, (gdouble) 0, (gdouble) _tmp0_, (gdouble) 0);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	p = _tmp1_;
#line 53 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	cairo_pattern_add_color_stop_rgba (p, (gdouble) 0, (gdouble) 0, (gdouble) 0, (gdouble) 0, 0.4);
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	cairo_pattern_add_color_stop_rgba (p, 0.7, (gdouble) 0, (gdouble) 0, (gdouble) 0, 0.0);
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp2_ = cr;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	cairo_set_source (_tmp2_, p);
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp3_ = cr;
#line 56 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	cairo_set_operator (_tmp3_, CAIRO_OPERATOR_SOURCE);
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp4_ = cr;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp5_ = w;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp6_ = h;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	cairo_rectangle (_tmp4_, (gdouble) 0, (gdouble) 0, (gdouble) _tmp5_, (gdouble) _tmp6_);
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp7_ = cr;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	cairo_fill (_tmp7_);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	result = TRUE;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_cairo_pattern_destroy0 (p);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	return result;
#line 477 "sidebar.c"
}


static gboolean ___lambda42__clutter_canvas_draw (ClutterCanvas* _sender, cairo_t* cr, gint width, gint height, gpointer self) {
	gboolean result;
	result = __lambda42_ (self, cr, width, height);
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	return result;
#line 486 "sidebar.c"
}


static void boxes_sidebar_setup_sidebar (BoxesSidebar* self) {
	ClutterActor* _tmp0_;
	ClutterBinLayout* _tmp1_;
	ClutterBinLayout* bin;
	ClutterActor* _tmp2_;
	ClutterBinLayout* _tmp3_;
	ClutterActor* _tmp4_;
	ClutterActor* _tmp5_;
	ClutterActor* shadow;
	ClutterActor* _tmp6_;
	ClutterCanvas* _tmp7_;
	ClutterCanvas* canvas;
	ClutterCanvas* _tmp8_;
	ClutterCanvas* _tmp9_;
	ClutterActor* _tmp10_;
	ClutterCanvas* _tmp11_;
	ClutterActor* _tmp12_;
	ClutterActor* _tmp13_;
	ClutterActor* _tmp14_;
	ClutterActor* _tmp15_;
	ClutterActor* _tmp16_;
	ClutterActor* _tmp17_;
	ClutterActor* _tmp18_;
	GtkClutterTexture* _tmp19_;
	GtkClutterTexture* background;
	GtkClutterTexture* _tmp20_;
	GtkClutterTexture* _tmp27_;
	GtkClutterTexture* _tmp28_;
	GtkClutterTexture* _tmp29_;
	GtkClutterTexture* _tmp30_;
	ClutterActor* _tmp31_;
	GtkClutterTexture* _tmp32_;
	GtkNotebook* _tmp33_;
	GtkNotebook* _tmp34_;
	GtkClutterActor* _tmp35_;
	GtkClutterActor* _tmp36_;
	GtkWidget* _tmp37_ = NULL;
	GtkStyleContext* _tmp38_ = NULL;
	GtkClutterActor* _tmp39_;
	GtkClutterActor* _tmp40_;
	GtkClutterActor* _tmp41_;
	ClutterActor* _tmp42_;
	GtkClutterActor* _tmp43_;
	GtkNotebook* _tmp44_;
	GtkStyleContext* _tmp45_ = NULL;
	GtkNotebook* _tmp46_;
	GtkStyleContext* _tmp47_ = NULL;
	GtkNotebook* _tmp48_;
	guint _tmp49_;
	GtkNotebook* _tmp50_;
	GtkBox* _tmp51_;
	GtkBox* vbox;
	GtkNotebook* _tmp52_;
	GtkBox* _tmp53_;
	GtkBox* _tmp54_;
	GtkBox* _tmp55_;
	GtkNotebook* _tmp56_;
	GtkBox* _tmp57_;
	GtkBox* _tmp58_;
	GtkNotebook* _tmp59_;
	GtkBox* _tmp60_;
	GtkNotebook* _tmp61_;
	GError * _inner_error_ = NULL;
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_return_if_fail (self != NULL);
#line 42 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp0_ = clutter_actor_new ();
#line 42 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_object_ref_sink (_tmp0_);
#line 42 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (self->priv->bin_actor);
#line 42 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	self->priv->bin_actor = _tmp0_;
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp1_ = (ClutterBinLayout*) clutter_bin_layout_new (CLUTTER_BIN_ALIGNMENT_START, CLUTTER_BIN_ALIGNMENT_START);
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_object_ref_sink (_tmp1_);
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	bin = _tmp1_;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp2_ = self->priv->bin_actor;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp3_ = bin;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	clutter_actor_set_layout_manager (_tmp2_, (ClutterLayoutManager*) _tmp3_);
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp4_ = self->priv->bin_actor;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	clutter_actor_set_name (_tmp4_, "sidebar-bin");
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp5_ = clutter_actor_new ();
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_object_ref_sink (_tmp5_);
#line 48 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	shadow = _tmp5_;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp6_ = shadow;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	clutter_actor_set_width (_tmp6_, (gfloat) BOXES_SIDEBAR_shadow_width);
#line 50 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp7_ = clutter_canvas_new ();
#line 50 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	canvas = _tmp7_;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp8_ = canvas;
#line 51 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_signal_connect_object (_tmp8_, "draw", (GCallback) ___lambda42__clutter_canvas_draw, self, 0);
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp9_ = canvas;
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	clutter_canvas_set_size (_tmp9_, BOXES_SIDEBAR_shadow_width, 1);
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp10_ = shadow;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp11_ = canvas;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	clutter_actor_set_content (_tmp10_, (ClutterContent*) _tmp11_);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp12_ = shadow;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	clutter_actor_set_content_gravity (_tmp12_, CLUTTER_CONTENT_GRAVITY_RESIZE_FILL);
#line 65 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp13_ = shadow;
#line 65 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	clutter_actor_set_content_scaling_filters (_tmp13_, CLUTTER_SCALING_FILTER_NEAREST, CLUTTER_SCALING_FILTER_NEAREST);
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp14_ = shadow;
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	clutter_actor_set_x_align (_tmp14_, CLUTTER_ACTOR_ALIGN_END);
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp15_ = shadow;
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	clutter_actor_set_x_expand (_tmp15_, TRUE);
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp16_ = shadow;
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	clutter_actor_set_y_expand (_tmp16_, TRUE);
#line 69 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp17_ = self->priv->bin_actor;
#line 69 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp18_ = shadow;
#line 69 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	clutter_actor_add_child (_tmp17_, _tmp18_);
#line 71 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp19_ = (GtkClutterTexture*) gtk_clutter_texture_new ();
#line 71 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_object_ref_sink (_tmp19_);
#line 71 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	background = _tmp19_;
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp20_ = background;
#line 72 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	clutter_actor_set_name ((ClutterActor*) _tmp20_, "sidebar-background");
#line 643 "sidebar.c"
	{
		gchar* _tmp21_ = NULL;
		gchar* _tmp22_;
		GdkPixbuf* _tmp23_;
		GdkPixbuf* _tmp24_;
		GdkPixbuf* pixbuf;
		GtkClutterTexture* _tmp25_;
		GdkPixbuf* _tmp26_;
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
		_tmp21_ = boxes_get_style ("assets/boxes-gray.png");
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
		_tmp22_ = _tmp21_;
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
		_tmp23_ = gdk_pixbuf_new_from_file (_tmp22_, &_inner_error_);
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
		_tmp24_ = _tmp23_;
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
		_g_free0 (_tmp22_);
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
		pixbuf = _tmp24_;
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
		if (_inner_error_ != NULL) {
#line 666 "sidebar.c"
			goto __catch62_g_error;
		}
#line 75 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
		_tmp25_ = background;
#line 75 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
		_tmp26_ = pixbuf;
#line 75 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
		gtk_clutter_texture_set_from_pixbuf (_tmp25_, _tmp26_, &_inner_error_);
#line 75 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
		if (_inner_error_ != NULL) {
#line 75 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
			_g_object_unref0 (pixbuf);
#line 679 "sidebar.c"
			goto __catch62_g_error;
		}
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
		_g_object_unref0 (pixbuf);
#line 684 "sidebar.c"
	}
	goto __finally62;
	__catch62_g_error:
	{
		GError* e = NULL;
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
		e = _inner_error_;
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
		_inner_error_ = NULL;
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
		_g_error_free0 (e);
#line 696 "sidebar.c"
	}
	__finally62:
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	if (_inner_error_ != NULL) {
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
		_g_object_unref0 (background);
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
		_g_object_unref0 (canvas);
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
		_g_object_unref0 (shadow);
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
		_g_object_unref0 (bin);
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
		g_clear_error (&_inner_error_);
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
		return;
#line 715 "sidebar.c"
	}
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp27_ = background;
#line 78 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	clutter_texture_set_repeat ((ClutterTexture*) _tmp27_, TRUE, TRUE);
#line 79 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp28_ = background;
#line 79 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	clutter_actor_set_margin_right ((ClutterActor*) _tmp28_, (gfloat) BOXES_SIDEBAR_shadow_width);
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp29_ = background;
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	clutter_actor_set_x_expand ((ClutterActor*) _tmp29_, TRUE);
#line 81 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp30_ = background;
#line 81 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	clutter_actor_set_y_expand ((ClutterActor*) _tmp30_, TRUE);
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp31_ = self->priv->bin_actor;
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp32_ = background;
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	clutter_container_add ((ClutterContainer*) _tmp31_, (ClutterActor*) _tmp32_, NULL);
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp33_ = (GtkNotebook*) gtk_notebook_new ();
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_object_ref_sink (_tmp33_);
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (self->notebook);
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	self->notebook = _tmp33_;
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp34_ = self->notebook;
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp35_ = (GtkClutterActor*) gtk_clutter_actor_new_with_contents ((GtkWidget*) _tmp34_);
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_object_ref_sink (_tmp35_);
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (self->priv->gtk_actor);
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	self->priv->gtk_actor = _tmp35_;
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp36_ = self->priv->gtk_actor;
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp37_ = gtk_clutter_actor_get_widget (_tmp36_);
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp38_ = gtk_widget_get_style_context (_tmp37_);
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_style_context_add_class (_tmp38_, "boxes-bg");
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp39_ = self->priv->gtk_actor;
#line 87 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	clutter_actor_set_name ((ClutterActor*) _tmp39_, "sidebar");
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp40_ = self->priv->gtk_actor;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	clutter_actor_set_x_expand ((ClutterActor*) _tmp40_, TRUE);
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp41_ = self->priv->gtk_actor;
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	clutter_actor_set_y_expand ((ClutterActor*) _tmp41_, TRUE);
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp42_ = self->priv->bin_actor;
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp43_ = self->priv->gtk_actor;
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	clutter_actor_add_child (_tmp42_, (ClutterActor*) _tmp43_);
#line 91 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp44_ = self->notebook;
#line 91 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp45_ = gtk_widget_get_style_context ((GtkWidget*) _tmp44_);
#line 91 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_style_context_add_class (_tmp45_, GTK_STYLE_CLASS_SIDEBAR);
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp46_ = self->notebook;
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp47_ = gtk_widget_get_style_context ((GtkWidget*) _tmp46_);
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_style_context_add_class (_tmp47_, "boxes-bg");
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp48_ = self->notebook;
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp49_ = self->priv->width;
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_widget_set_size_request ((GtkWidget*) _tmp48_, (gint) _tmp49_, 100);
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp50_ = self->notebook;
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_notebook_set_show_tabs (_tmp50_, FALSE);
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp51_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_object_ref_sink (_tmp51_);
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	vbox = _tmp51_;
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp52_ = self->notebook;
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp53_ = vbox;
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_notebook_append_page (_tmp52_, (GtkWidget*) _tmp53_, NULL);
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp54_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_object_ref_sink (_tmp54_);
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (vbox);
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	vbox = _tmp54_;
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp55_ = vbox;
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_widget_set_margin_top ((GtkWidget*) _tmp55_, 20);
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp56_ = self->notebook;
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp57_ = vbox;
#line 103 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_notebook_append_page (_tmp56_, (GtkWidget*) _tmp57_, NULL);
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp58_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 10);
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_object_ref_sink (_tmp58_);
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (vbox);
#line 106 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	vbox = _tmp58_;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp59_ = self->notebook;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp60_ = vbox;
#line 107 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_notebook_append_page (_tmp59_, (GtkWidget*) _tmp60_, NULL);
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp61_ = self->notebook;
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp61_);
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (vbox);
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (background);
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (canvas);
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (shadow);
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (bin);
#line 863 "sidebar.c"
}


static ClutterActor* boxes_sidebar_real_get_actor (BoxesUI* base) {
	ClutterActor* result;
	BoxesSidebar* self;
	ClutterActor* _tmp0_;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	self = (BoxesSidebar*) base;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp0_ = self->priv->bin_actor;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	result = _tmp0_;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	return result;
#line 879 "sidebar.c"
}


static void boxes_sidebar_class_init (BoxesSidebarClass * klass) {
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	boxes_sidebar_parent_class = g_type_class_peek_parent (klass);
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_type_class_add_private (klass, sizeof (BoxesSidebarPrivate));
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	BOXES_UI_CLASS (klass)->ui_state_changed = boxes_sidebar_real_ui_state_changed;
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	BOXES_UI_CLASS (klass)->get_actor = boxes_sidebar_real_get_actor;
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_sidebar_get_property;
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_sidebar_finalize;
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SIDEBAR_ACTOR, g_param_spec_object ("actor", "actor", "actor", clutter_actor_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 898 "sidebar.c"
}


static void boxes_sidebar_instance_init (BoxesSidebar * self) {
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	self->priv = BOXES_SIDEBAR_GET_PRIVATE (self);
#line 905 "sidebar.c"
}


static void boxes_sidebar_finalize (GObject* obj) {
	BoxesSidebar * self;
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_SIDEBAR, BoxesSidebar);
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (self->notebook);
#line 18 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (self->priv->bin_actor);
#line 19 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (self->priv->gtk_actor);
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	G_OBJECT_CLASS (boxes_sidebar_parent_class)->finalize (obj);
#line 921 "sidebar.c"
}


GType boxes_sidebar_get_type (void) {
	static volatile gsize boxes_sidebar_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_sidebar_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesSidebarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_sidebar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesSidebar), 0, (GInstanceInitFunc) boxes_sidebar_instance_init, NULL };
		GType boxes_sidebar_type_id;
		boxes_sidebar_type_id = g_type_register_static (BOXES_TYPE_UI, "BoxesSidebar", &g_define_type_info, 0);
		g_once_init_leave (&boxes_sidebar_type_id__volatile, boxes_sidebar_type_id);
	}
	return boxes_sidebar_type_id__volatile;
}


static void _vala_boxes_sidebar_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesSidebar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_SIDEBAR, BoxesSidebar);
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
	switch (property_id) {
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
		case BOXES_SIDEBAR_ACTOR:
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
		g_value_set_object (value, boxes_ui_get_actor ((BoxesUI*) self));
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
		break;
#line 948 "sidebar.c"
		default:
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/sidebar.vala"
		break;
#line 954 "sidebar.c"
	}
}



